summaryrefslogtreecommitdiffstats
path: root/lib/kwmf/kowmfwrite.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kwmf/kowmfwrite.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kwmf/kowmfwrite.h')
-rw-r--r--lib/kwmf/kowmfwrite.h66
1 files changed, 33 insertions, 33 deletions
diff --git a/lib/kwmf/kowmfwrite.h b/lib/kwmf/kowmfwrite.h
index 1063ef76..bc3e1411 100644
--- a/lib/kwmf/kowmfwrite.h
+++ b/lib/kwmf/kowmfwrite.h
@@ -18,24 +18,24 @@
#ifndef _KOWMFWRITE_H_
#define _KOWMFWRITE_H_
-#include <qpen.h>
-#include <qbrush.h>
-#include <qcolor.h>
-#include <qfont.h>
-#include <qrect.h>
-#include <qbuffer.h>
-#include <qregion.h>
-#include <qstring.h>
-#include <qwmatrix.h>
-#include <qimage.h>
-#include <qptrlist.h>
-#include <qpointarray.h>
+#include <tqpen.h>
+#include <tqbrush.h>
+#include <tqcolor.h>
+#include <tqfont.h>
+#include <tqrect.h>
+#include <tqbuffer.h>
+#include <tqregion.h>
+#include <tqstring.h>
+#include <tqwmatrix.h>
+#include <tqimage.h>
+#include <tqptrlist.h>
+#include <tqpointarray.h>
#include <koffice_export.h>
class KoWmfWritePrivate;
/**
* KoWmfWrite allows to create a windows placeable meta file (WMF).
- * Most of the functions are compatible with QPainter format.
+ * Most of the functions are compatible with TQPainter format.
*
* sample of utilization:
* <pre>
@@ -49,13 +49,13 @@ class KoWmfWritePrivate;
class KOWMF_EXPORT KoWmfWrite
{
public:
- KoWmfWrite( const QString& fileName );
+ KoWmfWrite( const TQString& fileName );
virtual ~KoWmfWrite();
// -------------------------------------------------------------------------
// virtual Painter
- // for a good documentation : check QPainter documentation
+ // for a good documentation : check TQPainter documentation
/**
* Open the file. Returns true on success.
*/
@@ -75,15 +75,15 @@ public:
void setDefaultDpi( int dpi );
// Drawing tools
- void setFont( const QFont& f );
+ void setFont( const TQFont& f );
// the width of the pen is in logical coordinate
- void setPen( const QPen& p );
- void setBrush( const QBrush& b );
+ void setPen( const TQPen& p );
+ void setBrush( const TQBrush& b );
// Drawing attributes/modes
- void setBackgroundColor( const QColor& r );
+ void setBackgroundColor( const TQColor& r );
void setBackgroundMode( Qt::BGMode );
- void setRasterOp( Qt::RasterOp );
+ void setRasterOp( TQt::RasterOp );
// Change logical Coordinate
void setWindow( int left, int top , int width, int height );
@@ -91,7 +91,7 @@ public:
// Clipping
// the 'CoordinateMode' parameter is ommitted : always CoordPainter in wmf
// not yet implemented
- void setClipRegion( const QRegion& r );
+ void setClipRegion( const TQRegion& r );
void clipping( bool enable );
// Graphics drawing functions
@@ -103,34 +103,34 @@ public:
void drawArc( int left, int top, int width, int height, int a, int alen );
void drawPie( int left, int top, int width, int height, int a, int alen );
void drawChord( int left, int top, int width, int height, int a, int alen );
- void drawPolyline( const QPointArray& pa );
- void drawPolygon( const QPointArray& pa, bool winding=FALSE );
+ void drawPolyline( const TQPointArray& pa );
+ void drawPolygon( const TQPointArray& pa, bool winding=FALSE );
// drawPolyPolygon draw the XOR of a list of polygons
// listPa : list of polygons
- void drawPolyPolygon( QPtrList<QPointArray>& listPa, bool winding=FALSE );
- void drawImage( int left, int top, const QImage &, int sx = 0, int sy = 0, int sw = -1, int sh = -1 );
+ void drawPolyPolygon( TQPtrList<TQPointArray>& listPa, bool winding=FALSE );
+ void drawImage( int left, int top, const TQImage &, int sx = 0, int sy = 0, int sw = -1, int sh = -1 );
// Text drawing functions
// rotation = the degrees of rotation in counterclockwise
// not yet implemented
- void drawText( int x, int y, int w, int h, int flags, const QString &s, double rotation );
+ void drawText( int x, int y, int w, int h, int flags, const TQString &s, double rotation );
private:
//-----------------------------------------------------------------------------
- // Utilities and conversion Qt --> Wmf
+ // Utilities and conversion TQt --> Wmf
- /** Convert QPointArray into Q_INT16 position (result in mSt) */
- void pointArray( const QPointArray& pa );
+ /** Convert TQPointArray into TQ_INT16 position (result in mSt) */
+ void pointArray( const TQPointArray& pa );
- /** Convertion between windows color and QColor */
- Q_UINT32 winColor( QColor color );
+ /** Convertion between windows color and TQColor */
+ TQ_UINT32 winColor( TQColor color );
/** Convert angle a and alen in coordinate (xStart,yStart) and (xEnd, yEnd) */
void angleToxy( int& xStart, int& yStart, int& xEnd, int& yEnd, int a, int alen );
/** Convert windows rasterOp in QT rasterOp */
- Q_UINT16 qtRasterToWin16( Qt::RasterOp op ) const;
- Q_UINT32 qtRasterToWin32( Qt::RasterOp op ) const;
+ TQ_UINT16 qtRasterToWin16( TQt::RasterOp op ) const;
+ TQ_UINT32 qtRasterToWin32( TQt::RasterOp op ) const;
private: